==> rice-impex-server-demo-2.1.14-sql.jar: sql/mysql/KRIM_PRNCPL_T.sql <==
TRUNCATE TABLE KRIM_PRNCPL_T
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1',STR_TO_DATE( '20081107094902', '%Y%m%d%H%i%s' ),'5B1B6B919CCA6496E0404F8189D822F2','1','kr',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1100',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C56110E0404F8189D85213','admin','admin',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1125',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C66110E0404F8189D85213','admin1','admin1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1126',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C76110E0404F8189D85213','admin2','admin2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1129',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C86110E0404F8189D85213','dev1','dev1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1130',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C96110E0404F8189D85213','dev2','dev2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1135',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03CA6110E0404F8189D85213','director','director',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1121',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03CB6110E0404F8189D85213','doug','doug',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1116',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CC6110E0404F8189D85213','earl','earl',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1114',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CD6110E0404F8189D85213','edna','edna',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1137',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CE6110E0404F8189D85213','employee','employee',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1115',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CF6110E0404F8189D85213','eric','eric',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1117',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03D06110E0404F8189D85213','erin','erin',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1119',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03D16110E0404F8189D85213','fran','fran',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1120',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03D26110E0404F8189D85213','frank','frank',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1118',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D36110E0404F8189D85213','fred','fred',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1122',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D46110E0404F8189D85213','idm1','idm1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1123',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D56110E0404F8189D85213','idm2','idm2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1124',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D66110E0404F8189D85213','idm3','idm3',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1136',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BA6110E0404F8189D85213','kuluser','kuluser',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1133',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D76110E0404F8189D85213','newaccountuser','newacctusr',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1131',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BB6110E0404F8189D85213','notsys','notsys',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1132',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BC6110E0404F8189D85213','notsysadm','notsysadm',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1109',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D86110E0404F8189D85213','quickstart','quickstart',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1134',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03D96110E0404F8189D85213','supervisor','supervisr',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1127',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DA6110E0404F8189D85213','test1','test1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1128',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DB6110E0404F8189D85213','test2','test2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1101',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BD6110E0404F8189D85213','testadmin1','testadmin1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1102',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BE6110E0404F8189D85213','testadmin2','testadmin2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1103',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BF6110E0404F8189D85213','testuser1','testuser1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1104',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C06110E0404F8189D85213','testuser2','testuser2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1105',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C16110E0404F8189D85213','testuser3','testuser3',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1106',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C26110E0404F8189D85213','testuser4','testuser4',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1107',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C36110E0404F8189D85213','testuser5','testuser5',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1108',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C46110E0404F8189D85213','testuser6','testuser6',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1110',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DC6110E0404F8189D85213','user1','user1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1111',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DD6110E0404F8189D85213','user2','user2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1112',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DE6110E0404F8189D85213','user3','user3',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1113',STR_TO_DATE( '20081113140648', '%Y%m%d%H%i%s' ),'5B97C50B03DF6110E0404F8189D85213','user4','user4',1)
/

==> rice-impex-server-demo-2.5.11-sql.jar: sql/mysql/KRIM_PRNCPL_T.sql <==
TRUNCATE TABLE KRIM_PRNCPL_T
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1',STR_TO_DATE( '20081107094902', '%Y%m%d%H%i%s' ),'5B1B6B919CCA6496E0404F8189D822F2','1','kr',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1100',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C56110E0404F8189D85213','admin','admin',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1125',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C66110E0404F8189D85213','admin1','admin1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1126',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C76110E0404F8189D85213','admin2','admin2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1129',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C86110E0404F8189D85213','dev1','dev1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1130',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03C96110E0404F8189D85213','dev2','dev2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1135',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03CA6110E0404F8189D85213','director','director',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1121',STR_TO_DATE( '20081113140644', '%Y%m%d%H%i%s' ),'5B97C50B03CB6110E0404F8189D85213','doug','doug',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1116',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CC6110E0404F8189D85213','earl','earl',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1114',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CD6110E0404F8189D85213','edna','edna',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1137',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CE6110E0404F8189D85213','employee','employee',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1115',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03CF6110E0404F8189D85213','eric','eric',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1117',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03D06110E0404F8189D85213','erin','erin',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1119',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03D16110E0404F8189D85213','fran','fran',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1120',STR_TO_DATE( '20081113140645', '%Y%m%d%H%i%s' ),'5B97C50B03D26110E0404F8189D85213','frank','frank',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1118',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D36110E0404F8189D85213','fred','fred',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','KR1000',STR_TO_DATE( '20120929165351', '%Y%m%d%H%i%s' ),'CADAFF9BD4F44598E040F90A05B96699','guest','guest',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1122',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D46110E0404F8189D85213','idm1','idm1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1123',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D56110E0404F8189D85213','idm2','idm2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1124',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D66110E0404F8189D85213','idm3','idm3',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1136',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BA6110E0404F8189D85213','kuluser','kuluser',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1133',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D76110E0404F8189D85213','newaccountuser','newacctusr',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1131',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BB6110E0404F8189D85213','notsys','notsys',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1132',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BC6110E0404F8189D85213','notsysadm','notsysadm',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1109',STR_TO_DATE( '20081113140646', '%Y%m%d%H%i%s' ),'5B97C50B03D86110E0404F8189D85213','quickstart','quickstart',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1134',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03D96110E0404F8189D85213','supervisor','supervisr',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1127',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DA6110E0404F8189D85213','test1','test1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1128',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DB6110E0404F8189D85213','test2','test2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1101',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BD6110E0404F8189D85213','testadmin1','testadmin1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1102',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BE6110E0404F8189D85213','testadmin2','testadmin2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1103',STR_TO_DATE( '20081113140642', '%Y%m%d%H%i%s' ),'5B97C50B03BF6110E0404F8189D85213','testuser1','testuser1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1104',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C06110E0404F8189D85213','testuser2','testuser2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1105',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C16110E0404F8189D85213','testuser3','testuser3',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1106',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C26110E0404F8189D85213','testuser4','testuser4',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1107',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C36110E0404F8189D85213','testuser5','testuser5',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1108',STR_TO_DATE( '20081113140643', '%Y%m%d%H%i%s' ),'5B97C50B03C46110E0404F8189D85213','testuser6','testuser6',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1110',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DC6110E0404F8189D85213','user1','user1',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1111',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DD6110E0404F8189D85213','user2','user2',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1112',STR_TO_DATE( '20081113140647', '%Y%m%d%H%i%s' ),'5B97C50B03DE6110E0404F8189D85213','user3','user3',1)
/
INSERT INTO KRIM_PRNCPL_T (ACTV_IND,ENTITY_ID,LAST_UPDT_DT,OBJ_ID,PRNCPL_ID,PRNCPL_NM,VER_NBR)
  VALUES ('Y','1113',STR_TO_DATE( '20081113140648', '%Y%m%d%H%i%s' ),'5B97C50B03DF6110E0404F8189D85213','user4','user4',1)
/
